********************************************************************************
********************************************************************************
**** Presidential Prospects, Political Support and Stock Market Performance ****
**** Nikhar Gaikwad. Quarterly Journal of Political Science. 2013. 8(4) 	****
**** Replication File. Email nikhar.gaikwad@yale.edu for questions/comments	****
********************************************************************************
********************************************************************************

clear
set more off  
* Set directory path to your own directory
cd "XXXX"

use foranalysis, clear

************************
*** Results: Table 1 ***
************************

* One-day Event Window
preserve
keep if date==date("2may2011","DMY")

* Column 1: Abnormal Returns
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full, robust cluster(hsiccd)

* Column 2: Raw Returns
* Panel A
reg ret1 total_d_10_full total_r_10_full, robust cluster(hsiccd) 
* Panel B
reg ret1 total_d_08_full total_r_08_full, robust cluster(hsiccd) 

* Column 3: Firm-Specific Controls
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

* Column 4: Intensive Margins
* Panel A
reg ab_ret1 total_d_10 total_r_10 ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08 total_r_08 ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

* Column 5: Include Regulated Industries Dummy
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full reg_dum ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full reg_dum ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

* Column 6: Include Industry-Less-Own Contributions 
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full indlessown_d_10_full indlessown_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full indlessown_d_08_full indlessown_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

* Column 7: DV as Abnormal Returns Dummy
* Panel A
reg ab_ret_dum total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret_dum total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

restore

* One-week Event Window
preserve
keep if date==date("6may2011","DMY")

* Column 8: One-week event window
* Panel A
reg ab_ret5 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret5 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

restore

*************************************************************************************
*** Sensitivity: Footnote 12 (Table 1, using data excluding "negative" donations) ***
*************************************************************************************

* One-day Event Window
preserve
keep if date==date("2may2011","DMY")

* Column 1: Abnormal Returns
* Panel A
reg ab_ret1 total_d_pos_10_full total_r_pos_10_full, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_pos_08_full total_r_pos_08_full, robust cluster(hsiccd)

* Column 2: Raw Returns
* Panel A
reg ret1 total_d_pos_10_full total_r_pos_10_full, robust cluster(hsiccd) 
* Panel B
reg ret1 total_d_pos_08_full total_r_pos_08_full, robust cluster(hsiccd) 

* Column 3: Firm-Specific Controls
* Panel A
reg ab_ret1 total_d_pos_10_full total_r_pos_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_pos_08_full total_r_pos_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

* Column 4: Intensive Margins
* Panel A
reg ab_ret1 total_d_pos_10 total_r_pos_10 ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_pos_08 total_r_pos_08 ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

* Column 5: Include Regulated Industries Dummy
* Panel A
reg ab_ret1 total_d_pos_10_full total_r_pos_10_full reg_dum ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_pos_08_full total_r_pos_08_full reg_dum ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

* Column 6: Include Industry-Less-Own Contributions 
* Panel A
reg ab_ret1 total_d_pos_10_full total_r_pos_10_full indlessown_d_10_full indlessown_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_pos_08_full total_r_pos_08_full indlessown_d_08_full indlessown_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

* Column 7: DV as Abnormal Returns Dummy
* Panel A
reg ab_ret_dum total_d_pos_10_full total_r_pos_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret_dum total_d_pos_08_full total_r_pos_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

restore

* Five trading day event window
preserve
keep if date==date("6may2011","DMY")

* Column 8: One-week event window
* Panel A
reg ab_ret5 total_d_pos_10_full total_r_pos_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret5 total_d_pos_08_full total_r_pos_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

restore


****************************************************************************************
*** Sensitivity: Footnote 12 (Table 1, standard errors clustered at 3-digit SIC code ***
****************************************************************************************

* One-day Event Window
preserve
keep if date==date("2may2011","DMY")

* Column 1: Abnormal Returns
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full, robust cluster(hsicig)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full, robust cluster(hsicig)

* Column 2: Raw Returns
* Panel A
reg ret1 total_d_10_full total_r_10_full, robust cluster(hsicig) 
* Panel B
reg ret1 total_d_08_full total_r_08_full, robust cluster(hsicig) 

* Column 3: Firm-Specific Controls
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)

* Column 4: Intensive Margins
* Panel A
reg ab_ret1 total_d_10 total_r_10 ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)
* Panel B
reg ab_ret1 total_d_08 total_r_08 ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)

* Column 5: Include Regulated Industries Dummy
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full reg_dum ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full reg_dum ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)

* Column 6: Include Industry-Less-Own Contributions 
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full indlessown_d_10_full indlessown_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full indlessown_d_08_full indlessown_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)

* Column 7: DV as Abnormal Returns Dummy
* Panel A
reg ab_ret_dum total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)
* Panel B
reg ab_ret_dum total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)

restore

* One-week Event Window
preserve
keep if date==date("6may2011","DMY")

* Column 8: One-week event window
* Panel A
reg ab_ret5 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)
* Panel B
reg ab_ret5 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsicig)

restore


*************************
*** Results: Figure 1 ***
*************************

* Specification from Table 1, Column 3, Panel A

* One-day Event Window
preserve
keep if date==date("2may2011","DMY")
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

* Two-day Event Window
preserve
keep if date==date("3may2011","DMY")
reg ab_ret2 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

* Three-day Event Window
preserve
keep if date==date("4may2011","DMY")
reg ab_ret3 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

* Four-day Event Window
preserve
keep if date==date("5may2011","DMY")
reg ab_ret4 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

* Five-day Event Window
preserve
keep if date==date("6may2011","DMY")
reg ab_ret5 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

* Coefficients and 95% CIs from above models charted in file "QJPS Figures.xls"

**************************************************************************************************************
*** Results: Market Capitalization Change (in Abstract and last paragraph of "Empirical Findings" section) ***
**************************************************************************************************************

* Specification from Table 1, Column 3, Panel A
* One-day Event Window
preserve
keep if date==date("2may2011","DMY")
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
predict ab_firm_ret1, resid 
bysort tickerid: gen marketval1= ab_firm_ret1 * mar_cap_4_29
replace marketval1 =abs(marketval1)
total marketval1
gen marketval1_sum=sum(marketval1)
outsheet ticker_long comnam marketval1_sum using "marketval1_sum.csv", comma replace
restore

*** Five-day Event Window
preserve
keep if date==date("6may2011","DMY")
reg ab_ret5 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
predict ab_firm_ret5, resid 
bysort tickerid: gen marketval5= ab_firm_ret5 * mar_cap_4_29
replace marketval5=abs(marketval5)
total marketval5
gen marketval5_sum=sum(marketval5)
outsheet ticker_long comnam marketval5_sum using "marketval5_sum.csv", comma replace
restore

* Total market capital changes displayed in outsheet files (variables marketval1_sum amd marketval5_sum, last row of data)

*************************
*** Results: Figure 2 ***
*************************

use TAQ_trades, clear

drop if (median_price_index_d>102 | median_price_index_d<98) & party==1
drop if (median_price_index_r>102 | median_price_index_r<98) & party==2
drop if (median_price_index_no>102 | median_price_index_no<98) & party==0

* Color version
set scheme s2color
graph set window fontface default
preserve
keep if date==date("29apr2011","DMY")
drop if eventtime>57600000 //drop after market close trades on May 2, 2011
drop if eventtime<50400000 // drop pre-market close trades
twoway (scatter median_price_index_r realtime if party==2, msymbol(point) msize(large) mcolor(red)) ///
	   (scatter median_price_index_d realtime if party==1, msymbol(point) msize(large) mcolor(blue)) ///
       , name(gr1, replace) legend(off) fxsize(31) ytitle("") xtitle("Friday, April 29", size(2.5) color(black)) ylabel(98(2)102, nogrid labsize(2.5)) graphregion(color(white)) xlabel(minmax, labsize(vsmall) noticks format(%tchh:MM)) xmlabel(##2, noticks labsize(vsmall) format(%tchh:MM)) xline(1619712000000, lcolor(black) lwidth(medthin) lpattern(dash)) ttext(102 1619712000000 "April 29:  Trading Close", place(sw) orientation(vertical) size(3) color(black)) 
restore

preserve
keep if date==date("02may2011","DMY")
drop if eventtime>57600000 //drop after market close trades on May 2, 2011
drop if eventtime<34200000 // drop pre-market close trades
twoway (scatter median_price_index_r realtime if party==2, msymbol(point) msize(large) mcolor(red)) ///
	   (scatter median_price_index_d realtime if party==1, msymbol(point) msize(large) mcolor(blue)) ///
       , name(gr2, replace) legend(off)  ytitle("")  xtitle("Monday, May 2", size(2.5) color(black)) yscale(off) ylabel(98(2)102, nogrid labsize(2.5)) graphregion(color(white)) xlabel(minmax, labsize(vsmall) noticks format(%tchh:MM)) xmlabel(##6, noticks labsize(vsmall) format(%tchh:MM)) xline(1619947800000, lcolor(black) lwidth(vthin) lpattern(dash)) ttext(97.89 1619947800000 "May 2:  Trading Start" "Post-Bin Laden Death", place(ne) orientation(vertical) size(3) color(black))
restore

graph combine gr1 gr2, cols(2) imargin(zero) ycommon l2title(Trades Indexed to April 29 Closing Prices, size(2.5)) b2title(Trading Hours, size(2.5)) title("{bf:Figure 2:  Intraday trades for politically oriented firms}", justification(left) color(black) size(4) bexpand) subtitle("April 29, 2011 - May 2, 2011", size(3) justification(left) bexpand) note("Plots represent medians of all trades during every second of the trading day for firms that donated." "Red (blue) plots represent trades of Republican (Democratic) oriented firms." "Outlier trades are excluded. If a firm donated to both parties, it is assigned to the party that received greater donations.", size(2.5)) graphregion(color(white))  
graph export Figures/Figure2COLOR.png, width(600) replace
graph export Figures/Figure2COLOR.eps, replace

* Black & White version
set scheme s1mono
graph set window fontface default
preserve
keep if date==date("29apr2011","DMY")
drop if eventtime>57600000 //drop after market close trades on May 2, 2011
drop if eventtime<50400000 // drop pre-market close trades
twoway (scatter median_price_index_r realtime if party==2, msymbol(point) msize(large) mcolor(white)) ///
	   (scatter median_price_index_d realtime if party==1, msymbol(point) msize(large) mcolor(black)) ///
       , name(gr1, replace) legend(off) fxsize(31) ytitle("") xtitle("Friday, April 29", size(2.5) color(black)) ylabel(98(2)102, nogrid labsize(2.5)) graphregion(color(white)) xlabel(minmax, labsize(vsmall) noticks format(%tchh:MM)) xmlabel(##2, noticks labsize(vsmall) format(%tchh:MM)) xline(1619712000000, lcolor(black) lwidth(medthin) lpattern(dash)) ttext(102 1619712000000 "April 29:  Trading Close", place(sw) orientation(vertical) size(3) color(black)) graphregion(ifcolor(white) fcolor(white)) plotregion(ifcolor(gs10) fcolor(gs10) ilcolor(gs10) style(none)) 
restore

preserve
keep if date==date("02may2011","DMY")
drop if eventtime>57600000 //drop after market close trades on May 2, 2011
drop if eventtime<34200000 // drop pre-market close trades
twoway (scatter median_price_index_r realtime if party==2, msymbol(point) msize(large) mcolor(white)) ///
	   (scatter median_price_index_d realtime if party==1, msymbol(point) msize(large) mcolor(black)) ///
       , name(gr2, replace) legend(off)  ytitle("")  xtitle("Monday, May 2", size(2.5) color(black)) yscale(off) ylabel(98(2)102, nogrid labsize(2.5)) graphregion(color(white)) xlabel(minmax, labsize(vsmall) noticks format(%tchh:MM)) xmlabel(##6, noticks labsize(vsmall) format(%tchh:MM)) xline(1619947800000, lcolor(black) lwidth(vthin) lpattern(dash)) ttext(97.89 1619947800000 "May 2:  Trading Start" "Post-Bin Laden Death", place(ne) orientation(vertical) size(3) color(black)) graphregion(ifcolor(white)) plotregion(ifcolor(gs10)fcolor(gs10) ilcolor(gs10) style(none))
restore

graph combine gr1 gr2, cols(2) imargin(zero) ycommon l2title(Trades Indexed to April 29 Closing Prices, size(2.5)) b2title(Trading Hours, size(2.5)) title("{bf:Figure 2:  Intraday trades for politically oriented firms}", justification(left) color(black) size(4) bexpand) subtitle("April 29, 2011 - May 2, 2011", size(3) justification(left) bexpand) note("Plots represent medians of all trades during every second of the trading day for firms that donated." "White (black) plots represent trades of Republican (Democratic) oriented firms." "Outlier trades are excluded. If a firm donated to both parties, it is assigned to the party that received greater donations.", size(2.5)) graphregion(color(white) fcolor(white)) plotregion(ifcolor(gs10) style(none)) 
graph export Figures/Figure2BW.png, width(600) replace
graph export Figures/Figure2BW.eps, replace



*********************************
*** Online Appendix: Table A1 ***
*********************************

* "S&P500 Companies' PAC Contributions" 

use totals_sp500, clear
sum total_08 
* Note: Multiply Democrat and Republican totals by 100,000 to get aggregate figures
sum total_d_08
sum total_r_08 

sum total_10 
sum total_d_10
sum total_r_10 

* "Event Study Analysis" and "Market Model Estimates" 

use foranalysis, clear
* One-day window
preserve
keep if date==date("2may2011","DMY")
sum ab_alpha
sum ab_beta
sum ab_ret1
sum ret1
sum mcap1
sum ab_mcap1
restore

* One-week window
preserve
keep if date==date("6may2011","DMY")
sum ab_alpha
sum ab_beta
sum ab_ret5
sum ret5
sum mcap5
sum ab_mcap5
restore

**********************************
*** Online Appendix: Figure A1 ***
**********************************

* Six-day Event Window
preserve
keep if date==date("9may2011","DMY")
reg ab_ret6 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

* Seven-day Event Window
preserve
keep if date==date("10may2011","DMY")
reg ab_ret7 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

* Eight-day Event Window
preserve
keep if date==date("11may2011","DMY")
reg ab_ret8 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

* Nine-day Event Window
preserve
keep if date==date("12may2011","DMY")
reg ab_ret9 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

* Ten-day Event Window
preserve
keep if date==date("13may2011","DMY")
reg ab_ret10 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

* Coefficients and 95% CIs charted in file "QJPS Replication Figures.xls"

*********************************
*** Online Appendix: Table A2 ***
*********************************

* One-day Event Window
preserve
keep if date==date("2may2011","DMY")

* Column 1: Exclude Aerospace & Defense Industry. SIC codes for Aerospace and Defense industries include: SIC 3721 Aircraft/SIC 3724 Aircraft Engines & Engine Parts/ SIC 3728 Aircraft Equipment & Parts/ 3761 Guided Missiles & Space Vehicles & Parts/SIC 3764 Guided Missile & Space Vehicle Propulsion Units & Parts/SIC 3769 Guided Missile & Space Vehicle Launch Parts & Auxiliary Equipment Not Elsewhere Classified
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth if hsiccd != 3721 & hsiccd != 3724 & hsiccd != 3728 & hsiccd != 3761 & hsiccd != 3764 & hsiccd != 3769, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth if hsiccd != 3721 & hsiccd != 3724 & hsiccd != 3728 & hsiccd != 3761 & hsiccd != 3764 & hsiccd != 3769, robust cluster(hsiccd)

* Column 2: Exclude Oil & Natural Industries. SIC Codes for Oil and Natural Gas include: SIC 1311 Crude Petroleum & Natural Gas, 1381 Drilling Oil & Gas Wells, 1382 Oil & Gas Field Exploration Services, 1389 Oil & Gas Field Services
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth if hsiccd != 1311 & hsiccd != 1381 & hsiccd != 1382 & hsiccd != 1389, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth if hsiccd != 1311 & hsiccd != 1381 & hsiccd != 1382 & hsiccd != 1389, robust cluster(hsiccd)

* Column 3: Exclude Gold & Silver Industries. SIC codes for Gold and Silver Mining industries include: 1041 Gold Ores, 1044 Silver Ores
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth if hsiccd != 1041 & hsiccd != 1044, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth if hsiccd != 1041 & hsiccd != 1044, robust cluster(hsiccd)

* Column 4: Exclude Firms with Earnings Announcements. Bloomberg's list of top securities with earnings releases in the United States between 4/29/11-5/2/11 on S&P500: Humana Inc (HUM), Edison International (EIX), Chesapeake Energy Corp (CHK), Automatic Data Processing Inc (ADP), Anadarko Petroleum Corp (APC), Hartford Financial Services Group Inc (HIG), Davita Inc (DVA), Boston Properties (BXP), FirstEnergy Corp (FE)
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth if ticker != "HUM" & ticker != "EIX" & ticker != "CHK" & ticker != "ADP" & ticker != "APC" & ticker != "HIG" & ticker != "DVA" & ticker != "BXP" & ticker != "FE", robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth if ticker != "HUM" & ticker != "EIX" & ticker != "CHK" & ticker != "ADP" & ticker != "APC" & ticker != "HIG" & ticker != "DVA" & ticker != "BXP" & ticker != "FE", robust cluster(hsiccd)

* Column 5: Exclude Construction/Automobiles/Pharmaceutical Industries
* SIC codes for construction industry include: 1510 General building contractors, 1531 Operative builders, 1611 Highway and street construction, 1620 Heavy construction, except highway, and Special trade contractors: 1711 Plumbing, heating, and air conditioning, 1721 Painting, paperhanging, and decorating, 1731 Electrical work, 1740 Masonry, stonework, and plastering, 1750 Carpentering and flooring, 1761 Roofing and sheet metal work, 1771 Concrete work, 1781 Water well drilling, 1790 Miscellaneous special trade contractors.
* SIC codes for automobile industry include: 3710 Motor vehicles and equipment, 3725 Aircraft, guided missiles, and parts, 3730 Ship and boat building and repairing, 3798 Other transportation equipment, 3711 Motor Vehicles and Passenger Car Bodies, 3713 Truck and Bus Bodies, 3714 Motor Vehicle Parts and Accessories, 3715 Truck Trailers, 3716 Motor Homes
* SIC codes for pharmaceutical industry include: 2833 Medicinal Chemicals And Botanical Products, 2834 Pharmaceutical Preparation, 2835 In Vitro And In Vivo Diagnostic Substances, 2836 Biological Products, Except Diagnostic Substances
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth if hsiccd != 1510 & hsiccd != 1531 & hsiccd != 1611 & hsiccd != 1620 & hsiccd != 1711 & hsiccd != 1721 & hsiccd != 1731 & hsiccd != 1740 & hsiccd != 1750 & hsiccd != 1761 & hsiccd != 1771 & hsiccd != 1781 & hsiccd != 1790 & hsiccd != 3711 & hsiccd != 3713 & hsiccd != 3714 & hsiccd != 3715 & hsiccd != 3716 & hsiccd != 3710 & hsiccd != 3725 & hsiccd != 3730 & hsiccd != 3798 & hsiccd != 2833 & hsiccd != 2834 & hsiccd != 2835 & hsiccd != 2836, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth if hsiccd != 1510 & hsiccd != 1531 & hsiccd != 1611 & hsiccd != 1620 & hsiccd != 1711 & hsiccd != 1721 & hsiccd != 1731 & hsiccd != 1740 & hsiccd != 1750 & hsiccd != 1761 & hsiccd != 1771 & hsiccd != 1781 & hsiccd != 1790 & hsiccd != 3711 & hsiccd != 3713 & hsiccd != 3714 & hsiccd != 3715 & hsiccd != 3716 & hsiccd != 3710 & hsiccd != 3725 & hsiccd != 3730 & hsiccd != 3798 & hsiccd != 2833 & hsiccd != 2834 & hsiccd != 2835 & hsiccd != 2836, robust cluster(hsiccd)

* Column 6: Party Loyalty
* Panel A
reg ab_ret1 total_10_full fraction_dem10 demdon_dummy10 repdon_dummy10 ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_08_full fraction_dem08 demdon_dummy08 repdon_dummy08 ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

* Column 7: Rival Donations
* Panel A
reg ab_ret1 total_d_10_full total_r_10_full demdon_dummy10 repdon_dummy10 repdon_dum_dem10 ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* Panel B
reg ab_ret1 total_d_08_full total_r_08_full demdon_dummy08 repdon_dummy08 repdon_dum_dem08 ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)

restore


*********************************
*** Online Appendix: Table A3 ***
*********************************

* One day window
preserve
keep if date==date("25apr2011","DMY")
* 2008 cycle
reg ret1 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
reg ab_ret1 total_d_08_full total_r_08_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
* 2010 cycle
reg ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth, robust cluster(hsiccd)
restore

**********************************
*** Online Appendix: Figure A2 ***
**********************************

* Compare magnitude of coefficients on contributions to Democrats and Republicans, respectively, on 5/2/11 with the distribution of coefficients over 180 days prior to the event
* See file "QJPS_Figures.xls"

***********************************************
*** Online Appendix: Industry Fixed Effects ***
***********************************************

xi i.hsiccd

preserve
keep if date==date("2may2011","DMY")
reg ab_ret1 total_d_10_full total_r_10_full ln_total_assets asset_tang_ratio firm_leverage op_profitability sales_growth _Ihsiccd*, robust cluster(hsiccd)
restore

***********
*** End ***
***********
